Index: /trunk/source/visualization/OpenInventor/History
===================================================================
--- /trunk/source/visualization/OpenInventor/History	(revision 1287)
+++ /trunk/source/visualization/OpenInventor/History	(revision 1288)
@@ -1,3 +1,3 @@
-$Id: History,v 1.104 2009/11/17 17:47:49 allison Exp $
+$Id: History,v 1.105 2010/05/26 14:30:46 allison Exp $
 -------------------------------------------------------------------
 
@@ -20,4 +20,8 @@
 History file for visualization/OpenInventor
 -------------------------------------------
+
+26th May 2010  John Allison  (openinventor-V09-03-00)
+- G4OpenInventorWin.cc, G4OpenInventorXt.cc: Protection against
+  repeated initialisation.
 
 17th November 2009  John Allison  (openinventor-V09-02-03)
Index: /trunk/source/visualization/OpenInventor/src/G4OpenInventorWin.cc
===================================================================
--- /trunk/source/visualization/OpenInventor/src/G4OpenInventorWin.cc	(revision 1287)
+++ /trunk/source/visualization/OpenInventor/src/G4OpenInventorWin.cc	(revision 1288)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4OpenInventorWin.cc,v 1.7 2009/09/18 12:48:43 lgarnier Exp $
-// GEANT4 tag $Name:  $
+// $Id: G4OpenInventorWin.cc,v 1.8 2010/05/26 14:30:46 allison Exp $
+// GEANT4 tag $Name: openinventor-V09-03-00 $
 //
 // OpenInventor graphics system factory.
@@ -58,5 +58,5 @@
   HWND toplevel = (HWND)GetInteractorManager()->GetMainInteractor();
 
-  SoWin::init(toplevel);
+  if(!SoWin::getTopLevelWidget()) SoWin::init(toplevel);
 
   InitNodes();
Index: /trunk/source/visualization/OpenInventor/src/G4OpenInventorXt.cc
===================================================================
--- /trunk/source/visualization/OpenInventor/src/G4OpenInventorXt.cc	(revision 1287)
+++ /trunk/source/visualization/OpenInventor/src/G4OpenInventorXt.cc	(revision 1288)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4OpenInventorXt.cc,v 1.4 2006/06/29 21:22:24 gunter Exp $
-// GEANT4 tag $Name:  $
+// $Id: G4OpenInventorXt.cc,v 1.5 2010/05/26 14:30:46 allison Exp $
+// GEANT4 tag $Name: openinventor-V09-03-00 $
 //
 // 
@@ -81,5 +81,5 @@
   }
 
-  SoXt::init(top);
+  if(!SoXt::getTopLevelWidget()) SoXt::init(top);
 
   InitNodes();
Index: /trunk/source/visualization/gMocren/History
===================================================================
--- /trunk/source/visualization/gMocren/History	(revision 1287)
+++ /trunk/source/visualization/gMocren/History	(revision 1288)
@@ -1,3 +1,3 @@
-$Id: History,v 1.11 2010/05/11 10:44:35 allison Exp $
+$Id: History,v 1.13 2010/06/01 16:18:46 allison Exp $
 -------------------------------------------------------------------
 
@@ -20,4 +20,11 @@
 History file for visualization/gMocren sub-category
 ---------------------------------------------------
+
+1st May 2010  John Allison  (gMocren-V09-03-03)
+- G4GMocrenFileSceneHandler.cc: Removed dependency on G4VisManager.
+
+30th May 2010  John Allison  (gMocren-V09-03-02)
+- G4GMocrenFileSceneHandler: Added AddCompound(const G4VDigi&).
+  o Simply invokes G4VSceneHandler::AddCompound(const G4VDigi&) for now.
 
 11 May 2010  John Allison  (gMocren-V09-03-01)
Index: /trunk/source/visualization/gMocren/include/G4GMocrenFileSceneHandler.hh
===================================================================
--- /trunk/source/visualization/gMocren/include/G4GMocrenFileSceneHandler.hh	(revision 1287)
+++ /trunk/source/visualization/gMocren/include/G4GMocrenFileSceneHandler.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4GMocrenFileSceneHandler.hh,v 1.5 2009/11/01 14:37:10 akimura Exp $
+// $Id: G4GMocrenFileSceneHandler.hh,v 1.6 2010/05/30 10:04:16 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -103,4 +103,5 @@
   void AddCompound ( const G4VTrajectory& traj);
   void AddCompound ( const G4VHit& hit);
+  void AddCompound ( const G4VDigi& hit);
   void AddCompound ( const G4THitsMap<G4double> & hits);
 
Index: /trunk/source/visualization/gMocren/src/G4GMocrenFileSceneHandler.cc
===================================================================
--- /trunk/source/visualization/gMocren/src/G4GMocrenFileSceneHandler.cc	(revision 1287)
+++ /trunk/source/visualization/gMocren/src/G4GMocrenFileSceneHandler.cc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4GMocrenFileSceneHandler.cc,v 1.14 2010/05/11 10:44:11 allison Exp $
+// $Id: G4GMocrenFileSceneHandler.cc,v 1.16 2010/06/01 16:18:26 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -70,5 +70,5 @@
 #include "G4VVolumeMaterialScanner.hh"
 #include "G4VisTrajContext.hh"
-#include "G4VisManager.hh"
+#include "G4TrajectoriesModel.hh"
 #include "G4VTrajectoryModel.hh"
 #include "G4TrajectoryDrawByCharge.hh"
@@ -96,4 +96,5 @@
 const G4bool GFDEBUG_TRK = false;//true;
 const G4bool GFDEBUG_HIT = false;//true;
+const G4bool GFDEBUG_DIGI = false;//true;
 const G4int GFDEBUG_DET = 0; // 0: false 
 
@@ -1581,4 +1582,9 @@
 }
 
+void G4GMocrenFileSceneHandler::AddCompound( const G4VDigi & digi) {
+  if(GFDEBUG_DIGI) G4cout << " ::AddCompound(const G4VDigi&) >>>>>>>>> " << G4endl;
+  G4VSceneHandler::AddCompound(digi);
+}
+
 void G4GMocrenFileSceneHandler::AddCompound(const G4THitsMap<G4double> & hits) {
   if(GFDEBUG_HIT)
Index: /trunk/source/visualization/management/History
===================================================================
--- /trunk/source/visualization/management/History	(revision 1287)
+++ /trunk/source/visualization/management/History	(revision 1288)
@@ -1,3 +1,3 @@
-$Id: History,v 1.143 2010/05/20 07:56:21 allison Exp $
+$Id: History,v 1.150 2010/06/01 16:14:10 allison Exp $
 
 -------------------------------------------------------------------
@@ -26,4 +26,50 @@
 History file for visualization management sub-category
 ------------------------------------------------------
+
+1st June 2010  John Allison  (visman-V09-03-07)
+- G4VisManager:
+  o Made fVerbosity and GetVerbosity static (saves having to get vis
+    manager pointer).
+  o Some tidying.
+- G4VisCommandsSceneAdd.cc: Fixed compiler warning.
+
+30th May 2010  John Allison  (visman-V09-03-06)
+- Added /vis/scene/add/digiti[sz]ations.
+- Added /vis/filtering/digi.
+- G4VisManager, G4VisExecutive: Added registration and methods for digis.
+- G4VSceneHandler: Added AddCompound(const G4VDigi&).
+
+29th May 2010  John Allison  (visman-V09-03-05)
+- Co-works greps-V09-03-01 and tracking-V09-03-03.
+- G4VisManager:
+  o Introduced DispatchToModel without i_mode.
+  o Moved i-mode deprecation warning to G4VTrajectory.
+- G4VSceneHandler.cc:
+  o Moved i-mode deprecation warning to G4VTrajectory.
+- G4VisCommandsViewer.cc: /vis/viewer/rebuild:
+  o Added sceneHandler->ClearTransientStore().
+  o Added viewer->Set/Clear/DrawView().
+
+28th May 2010  John Allison  (visman-V09-03-04)
+- G4VisManager, G4VisExecutive:
+  Introduced optional verbosity string argument in constructor.  You
+  can now write, for example:
+    G4VisManager* visManager = new G4VisExecutive("quiet");
+  Note that the default is "warnings":
+    G4VisManager* visManager = new G4VisExecutive;
+
+28th May 2010  John Allison  (visman-V09-03-03)
+- Co-works interfaces-V09-03-04.
+- G4VisExecutive.icc: Change order of flags to follow G4UIExecutive.
+
+26th May 2010  John Allison  (visman-V09-03-02)
+- G4VisExecutive.icc: Added drivers with generic nicknames:
+  o OGL, OGLI, OGLS, OI.
+  o The specific driver depends on G4VIS_USE and G4UI_USE flags.  So,
+    for example, "/vis/open OGL" might open an OGLSX window on X or an
+    OGLSWin32 on Windows.  It means that example vis.mac scripts can
+    be written with this generic command that will work on all systems
+    and all user choices.  In particular, it will open an OGLSQt
+    window in a G4UIQt session.
 
 20th May 2010  John Allison  (visman-V09-03-01)
Index: /trunk/source/visualization/management/include/G4VisCommandsSceneAdd.hh
===================================================================
--- /trunk/source/visualization/management/include/G4VisCommandsSceneAdd.hh	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VisCommandsSceneAdd.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisCommandsSceneAdd.hh,v 1.19 2009/11/04 13:15:02 allison Exp $
+// $Id: G4VisCommandsSceneAdd.hh,v 1.20 2010/05/30 11:30:49 allison Exp $
 // GEANT4 tag $Name:  $
 
@@ -51,4 +51,17 @@
   G4VisCommandSceneAddAxes& operator = (const G4VisCommandSceneAddAxes&);
   G4UIcommand* fpCommand;
+};
+
+class G4VisCommandSceneAddDigis: public G4VVisCommandScene {
+public:
+  G4VisCommandSceneAddDigis ();
+  virtual ~G4VisCommandSceneAddDigis ();
+  G4String GetCurrentValue (G4UIcommand* command);
+  void SetNewValue (G4UIcommand* command, G4String newValue);
+private:
+  G4VisCommandSceneAddDigis (const G4VisCommandSceneAddDigis&);
+  G4VisCommandSceneAddDigis& operator = (const G4VisCommandSceneAddDigis&);
+  G4UIcmdWithoutParameter* fpCommand;
+  G4UIcmdWithoutParameter* fpCommandUS;
 };
 
Index: /trunk/source/visualization/management/include/G4VisExecutive.hh
===================================================================
--- /trunk/source/visualization/management/include/G4VisExecutive.hh	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VisExecutive.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisExecutive.hh,v 1.9 2009/11/17 15:34:06 allison Exp $
+// $Id: G4VisExecutive.hh,v 1.10 2010/05/28 16:48:03 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -56,5 +56,5 @@
 // #ifdef G4VIS_USE
 //   // Instantiate and initialise Visualization Manager.
-//   G4VisManager* visManager = new G4VisExecutive;    // See Nore (a).
+//   G4VisManager* visManager = new G4VisExecutive;    // See Note (a).
 //   visManager -> SetVerboseLevel (verbosityString);  // See Note (b).
 //   visManager -> RegisterGraphicsSystem (new myGS);  // See Note (c).
@@ -77,5 +77,7 @@
 // (b) The verbosityString ("quiet", "errors", "warnings",
 //     "confirmations", etc. - "help /vis/verbose" to see options) can be
-//     set here or with /vis/verbose.
+//     set here or with /vis/verbose.  Alternatively, you can instantiate
+//     with a verbosity string. e.g:
+//       G4VisManager* visManager = new G4VisExecutive("quiet");
 // (c) You can register your own graphics system like this.
 // (d) Your can intialise like this with C++ code or use /vis/initialize.
@@ -121,5 +123,5 @@
 public: // With description
 
-  G4VisExecutive () {}
+  G4VisExecutive (const G4String& verbosityString = "warnings");
 
 private:
Index: /trunk/source/visualization/management/include/G4VisExecutive.icc
===================================================================
--- /trunk/source/visualization/management/include/G4VisExecutive.icc	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VisExecutive.icc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisExecutive.icc,v 1.22 2009/10/12 11:54:50 akimura Exp $
+// $Id: G4VisExecutive.icc,v 1.26 2010/05/30 11:30:49 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -43,4 +43,5 @@
 #include "G4RayTracer.hh"
 #include "G4HitFilterFactories.hh"
+#include "G4DigiFilterFactories.hh"
 #include "G4TrajectoryFilterFactories.hh"
 #include "G4TrajectoryModelFactories.hh"
@@ -91,4 +92,8 @@
 #include "G4VRML2.hh"
 #endif
+
+  G4VisExecutive::G4VisExecutive (const G4String& verbosityString):
+    G4VisManager(verbosityString)	
+  {}
 
 // The inline keyword prevents the compiler making an external
@@ -118,4 +123,63 @@
 #endif
 
+// Register OGL graphics system with generic nicknames
+#ifdef G4VIS_USE_OPENGL
+  G4VGraphicsSystem* ogl  = 0;
+  G4VGraphicsSystem* ogli = 0;
+  G4VGraphicsSystem* ogls = 0;
+// Follow G4UIExecutive
+#if defined(G4UI_USE_QT)
+#ifdef G4VIS_USE_OPENGLQT
+  ogl  = new G4OpenGLStoredQt;
+  ogli = new G4OpenGLImmediateQt;
+  ogls = new G4OpenGLStoredQt;
+#endif
+#elif defined(G4UI_USE_XM)
+#ifdef G4VIS_USE_OPENGLXM
+  ogl  = new G4OpenGLStoredXm;
+  ogli = new G4OpenGLImmediateXm;
+  ogls = new G4OpenGLStoredXm;
+#endif
+#elif defined(G4UI_USE_WIN32)
+#ifdef G4VIS_USE_OPENGLWIN32
+  ogl  = new G4OpenGLStoredWin32;
+  ogli = new G4OpenGLImmediateWin32;
+  ogls = new G4OpenGLStoredWin32;
+#endif
+#elif defined(G4UI_USE_TCSH)
+#if defined (G4VIS_USE_OPENGLX)
+  ogl  = new G4OpenGLStoredX;
+  ogli = new G4OpenGLImmediateX;
+  ogls = new G4OpenGLStoredX;
+#elif defined (G4VIS_USE_OPENGLWIN32)
+  ogl  = new G4OpenGLStoredWin32;
+  ogli = new G4OpenGLImmediateWin32;
+  ogls = new G4OpenGLStoredWin32;
+#endif
+#else
+#if defined (G4VIS_USE_OPENGLX)
+  ogl  = new G4OpenGLStoredX;
+  ogli = new G4OpenGLImmediateX;
+  ogls = new G4OpenGLStoredX;
+#elif defined (G4VIS_USE_OPENGLWIN32)
+  ogl  = new G4OpenGLStoredWin32;
+  ogli = new G4OpenGLImmediateWin32;
+  ogls = new G4OpenGLStoredWin32;
+#endif
+#endif
+  if (ogl) {
+    ogl->SetNickName("OGL");
+    RegisterGraphicsSystem (ogl);
+  }
+  if (ogli) {
+    ogli->SetNickName("OGLI");
+    RegisterGraphicsSystem (ogli);
+  }
+  if (ogls) {
+    ogls->SetNickName("OGLS");
+    RegisterGraphicsSystem (ogls);
+  }
+#endif
+
 #ifdef G4VIS_USE_OPENGLX
   RegisterGraphicsSystem (new G4OpenGLImmediateX);
@@ -136,4 +200,19 @@
   RegisterGraphicsSystem (new G4OpenGLImmediateQt);
   RegisterGraphicsSystem (new G4OpenGLStoredQt);
+#endif
+
+// Register OI graphics system with generic nickname
+#ifdef G4VIS_USE_OI
+  G4VGraphicsSystem* oi  = 0;
+#ifdef G4VIS_USE_OIX
+  oi = new G4OpenInventorX;
+#endif
+#ifdef G4VIS_USE_OIWIN32
+  oi = new G4OpenInventorWin32;
+#endif
+  if (oi) {
+    oi->SetNickName("OI");
+    RegisterGraphicsSystem (oi);
+  }
 #endif
 
@@ -176,4 +255,7 @@
    // Hit filter models
    RegisterModelFactory(new G4HitAttributeFilterFactory());
+
+   // Digi filter models
+   RegisterModelFactory(new G4DigiAttributeFilterFactory());
 }
 
Index: /trunk/source/visualization/management/include/G4VisManager.hh
===================================================================
--- /trunk/source/visualization/management/include/G4VisManager.hh	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VisManager.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisManager.hh,v 1.71 2010/05/20 07:54:31 allison Exp $
+// $Id: G4VisManager.hh,v 1.75 2010/06/01 16:08:15 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -66,15 +66,16 @@
 //
 // Each scene comprises drawable objects such as detector components
-// and hits when appropriate.  A scene handler translates a scene into
-// graphics-system-specific function calls and, possibly, a
-// graphics-system-dependent database - display lists, scene graphs,
-// etc.  Each viewer has its "view parameters" (see class description
-// of G4ViewParameters for available parameters and also for a
-// description of the concept of a "standard view" and all that).
+// and trajectories, hits and digis when appropriate.  A scene handler
+// translates a scene into graphics-system-specific function calls
+// and, possibly, a graphics-system-dependent database - display
+// lists, scene graphs, etc.  Each viewer has its "view parameters"
+// (see class description of G4ViewParameters for available parameters
+// and also for a description of the concept of a "standard view" and
+// all that).
 //
 // A friend class G4VisStateDependent is "state dependent", i.e., it
 // is notified on change of state (G4ApplicationState).  This is used
-// to message the G4VisManager to draw hits and trajectories in the
-// current scene at the end of event, as required.
+// to message the G4VisManager to draw hits, digis and trajectories in
+// the current scene at the end of event, as required.
 
 #ifndef G4VISMANAGER_HH
@@ -113,4 +114,5 @@
   typedef G4VModelFactory< G4VFilter<G4VTrajectory> > G4TrajFilterFactory;
   typedef G4VModelFactory< G4VFilter<G4VHit> > G4HitFilterFactory;
+  typedef G4VModelFactory< G4VFilter<G4VDigi> > G4DigiFilterFactory;
 }
 
@@ -129,9 +131,6 @@
   friend class G4RayTracerSceneHandler;
   friend class G4RTMessenger;
-  friend class G4OpenGLStoredSceneHandler;
   friend class G4OpenGLViewerMessenger;
-  friend class G4OpenGLXViewerMessenger;
   friend class G4OpenGLXmViewerMessenger;
-  friend class G4XXXSceneHandler;
   friend class G4HepRepFileSceneHandler;
 
@@ -139,14 +138,10 @@
   friend class G4VSceneHandler;
   friend class G4VViewer;
-
-  friend std::ostream & operator <<
-  (std::ostream &, const G4VGraphicsSystem &);
-
-  friend std::ostream & operator <<
-  (std::ostream &, const G4VSceneHandler &);
-
   friend class G4VisStateDependent;
-
   friend class G4VisCommandList;
+
+  // operator << friends...
+  friend std::ostream& operator << (std::ostream&, const G4VGraphicsSystem&);
+  friend std::ostream& operator << (std::ostream&, const G4VSceneHandler&);
 
 public: // With description
@@ -165,5 +160,5 @@
 protected: // With description
 
-  G4VisManager ();
+  G4VisManager (const G4String& verbosityString = "warnings");
   // The constructor is protected so that an object of the derived
   // class may be constructed.
@@ -214,4 +209,10 @@
   void RegisterModel(G4VFilter<G4VHit>* filter);
   // Register trajectory hit model. Assumes ownership of model.
+
+  void RegisterModelFactory(G4DigiFilterFactory* factory);
+  // Register trajectory digi model factory. Assumes ownership of factory.
+
+  void RegisterModel(G4VFilter<G4VDigi>* filter);
+  // Register trajectory digi model. Assumes ownership of model.
 
   void SelectTrajectoryModel(const G4String& model);
@@ -281,4 +282,6 @@
   void Draw (const G4VHit&);
 
+  void Draw (const G4VDigi&);
+
   void Draw (const G4VTrajectory&, G4int i_mode);
   // i_mode is a parameter that can be used to control the drawing of
@@ -306,4 +309,5 @@
   // any, and redraw all views.
 
+  void DispatchToModel(const G4VTrajectory&);
   void DispatchToModel(const G4VTrajectory&, G4int i_mode);
   // Draw the trajectory.
@@ -311,4 +315,5 @@
   G4bool FilterTrajectory(const G4VTrajectory&);
   G4bool FilterHit(const G4VHit&);
+  G4bool FilterDigi(const G4VDigi&);
 
   ////////////////////////////////////////////////////////////////////////
@@ -329,6 +334,6 @@
   void EndOfEvent ();
   // This is called on change of state (G4ApplicationState).  It is
-  // used to draw hits and trajectories if included in the current
-  // scene at the end of event, as required.
+  // used to draw hits, digis and trajectories if included in the
+  // current scene at the end of event, as required.
 
   void EndOfRun ();
@@ -357,5 +362,5 @@
   const G4SceneHandlerList&    GetAvailableSceneHandlers   () const;
   const G4SceneList&           GetSceneList                () const;
-  Verbosity                    GetVerbosity                () const;
+  static Verbosity             GetVerbosity                ();
   G4bool                       GetTransientsDrawnThisRun       () const;
   G4bool                       GetTransientsDrawnThisEvent     () const;
@@ -445,5 +450,5 @@
   G4SceneList           fSceneList;
   G4SceneHandlerList    fAvailableSceneHandlers;
-  Verbosity             fVerbosity;
+  static Verbosity             fVerbosity;
   std::vector<G4UImessenger*> fMessengerList;
   std::vector<G4UIcommand*>   fDirectoryList;
@@ -467,4 +472,7 @@
   G4VisFilterManager<G4VHit>* fpHitFilterMgr;
 
+  // Digi filter model manager
+  G4VisFilterManager<G4VDigi>* fpDigiFilterMgr;
+
 };
 
Index: /trunk/source/visualization/management/include/G4VisManager.icc
===================================================================
--- /trunk/source/visualization/management/include/G4VisManager.icc	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VisManager.icc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisManager.icc,v 1.21 2009/01/13 09:55:15 lgarnier Exp $
+// $Id: G4VisManager.icc,v 1.22 2010/06/01 16:08:15 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -69,8 +69,7 @@
 }
 
-inline G4VisManager::Verbosity G4VisManager::GetVerbosity () const {
+inline G4VisManager::Verbosity G4VisManager::GetVerbosity () {
   return fVerbosity;
 }
-
 
 inline G4bool G4VisManager::GetTransientsDrawnThisEvent() const {
Index: /trunk/source/visualization/management/src/G4VSceneHandler.cc
===================================================================
--- /trunk/source/visualization/management/src/G4VSceneHandler.cc	(revision 1287)
+++ /trunk/source/visualization/management/src/G4VSceneHandler.cc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VSceneHandler.cc,v 1.92 2010/05/11 10:55:07 allison Exp $
+// $Id: G4VSceneHandler.cc,v 1.95 2010/06/01 16:08:15 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -75,4 +75,5 @@
 #include "G4HitsModel.hh"
 #include "G4VHit.hh"
+#include "G4VDigi.hh"
 #include "G4ScoringManager.hh"
 #include "G4DefaultLinearColorMap.hh"
@@ -263,5 +264,4 @@
   if (!trajectoriesModel) G4Exception
     ("G4VSceneHandler::AddCompound(const G4VTrajectory&): Not a G4TrajectoriesModel.");
-  G4VVisManager::IsDefaultDrawTrajectory = false;
   if (trajectoriesModel->IsDrawingModeSet()) {
     traj.DrawTrajectory(trajectoriesModel->GetDrawingMode());
@@ -269,16 +269,4 @@
     traj.DrawTrajectory();
   }
-  if (!G4VVisManager::IsDefaultDrawTrajectory) {
-    static G4bool warnedAboutIMode = false;
-    if (!warnedAboutIMode) {
-      G4Exception
-	("G4VSceneHandler::AddCompound(const G4VTrajectory&)",
-	 "",
-	 JustWarning,
-  "WARNING: DEPRECATED: The use of the i_mode argument in DrawTrajectory"
-  "\n  is deprecated and will be removed in a future major release.");
-      warnedAboutIMode = true;
-    }
-  }
 }
 
@@ -286,4 +274,9 @@
   // Cast away const because Draw is non-const!!!!
   const_cast<G4VHit&>(hit).Draw();
+}
+
+void G4VSceneHandler::AddCompound (const G4VDigi& digi) {
+  // Cast away const because Draw is non-const!!!!
+  const_cast<G4VDigi&>(digi).Draw();
 }
 
@@ -498,6 +491,5 @@
     }
     else {
-      G4VisManager::Verbosity verbosity =
-	G4VisManager::GetInstance()->GetVerbosity();
+      G4VisManager::Verbosity verbosity = G4VisManager::GetVerbosity();
       if (verbosity >= G4VisManager::errors) {
 	G4cout <<
@@ -519,6 +511,5 @@
     }
     else {
-      G4VisManager::Verbosity verbosity =
-	G4VisManager::GetInstance()->GetVerbosity();
+      G4VisManager::Verbosity verbosity = G4VisManager::GetVerbosity();
       if (verbosity >= G4VisManager::errors) {
 	G4cout <<
@@ -754,5 +745,5 @@
 
   pModelingParams->SetWarning
-    (G4VisManager::GetInstance()->GetVerbosity() >= G4VisManager::warnings);
+    (G4VisManager::GetVerbosity() >= G4VisManager::warnings);
 
   pModelingParams->SetExplodeFactor(vp.GetExplodeFactor());
Index: /trunk/source/visualization/management/src/G4VisCommandsSceneAdd.cc
===================================================================
--- /trunk/source/visualization/management/src/G4VisCommandsSceneAdd.cc	(revision 1287)
+++ /trunk/source/visualization/management/src/G4VisCommandsSceneAdd.cc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisCommandsSceneAdd.cc,v 1.79 2010/05/11 10:58:49 allison Exp $
+// $Id: G4VisCommandsSceneAdd.cc,v 1.81 2010/06/01 16:08:15 allison Exp $
 // GEANT4 tag $Name:  $
 // /vis/scene commands - John Allison  9th August 1998
@@ -37,4 +37,5 @@
 #include "G4ModelingParameters.hh"
 #include "G4HitsModel.hh"
+#include "G4DigiModel.hh"
 #include "G4PSHitsModel.hh"
 #include "G4TrajectoriesModel.hh"
@@ -157,4 +158,56 @@
 }
 
+
+////////////// /vis/scene/add/digis ///////////////////////////////////////
+
+G4VisCommandSceneAddDigis::G4VisCommandSceneAddDigis () {
+  fpCommand = new G4UIcmdWithoutParameter ("/vis/scene/add/digitisations", this);
+  fpCommand -> SetGuidance ("Adds digis to current scene.");
+  fpCommand -> SetGuidance
+    ("Digis are drawn at end of event when the scene in which"
+     "\nthey are added is current.");
+
+  fpCommandUS = new G4UIcmdWithoutParameter ("/vis/scene/add/digitizations", this);
+  fpCommandUS -> SetGuidance ("Adds digis to current scene.");
+  fpCommandUS -> SetGuidance
+    ("Digis are drawn at end of event when the scene in which"
+     "\nthey are added is current.");
+}
+
+G4VisCommandSceneAddDigis::~G4VisCommandSceneAddDigis () {
+  delete fpCommandUS;
+  delete fpCommand;
+}
+
+G4String G4VisCommandSceneAddDigis::GetCurrentValue (G4UIcommand*) {
+  return "";
+}
+
+void G4VisCommandSceneAddDigis::SetNewValue (G4UIcommand*, G4String) {
+
+  G4VisManager::Verbosity verbosity = fpVisManager->GetVerbosity();
+  G4bool warn(verbosity >= G4VisManager::warnings);
+
+  G4Scene* pScene = fpVisManager->GetCurrentScene();
+  if (!pScene) {
+    if (verbosity >= G4VisManager::errors) {
+      G4cout <<	"ERROR: No current scene.  Please create one." << G4endl;
+    }
+    return;
+  }
+
+  G4DigiModel* model = new G4DigiModel;
+  const G4String& currentSceneName = pScene -> GetName ();
+  G4bool successful = pScene -> AddEndOfEventModel (model, warn);
+  if (successful) {
+    if (verbosity >= G4VisManager::confirmations) {
+      G4cout << "Digis will be drawn in scene \""
+	     << currentSceneName << "\"."
+	     << G4endl;
+    }
+  }
+  else G4VisCommandsSceneAddUnsuccessful(verbosity);
+  UpdateVisManagerScene (currentSceneName);
+}
 
 ////////////// /vis/scene/add/eventID ///////////////////////////////////////
Index: /trunk/source/visualization/management/src/G4VisCommandsViewer.cc
===================================================================
--- /trunk/source/visualization/management/src/G4VisCommandsViewer.cc	(revision 1287)
+++ /trunk/source/visualization/management/src/G4VisCommandsViewer.cc	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VisCommandsViewer.cc,v 1.75 2009/01/19 15:47:49 lgarnier Exp $
+// $Id: G4VisCommandsViewer.cc,v 1.76 2010/05/29 21:20:20 allison Exp $
 // GEANT4 tag $Name:  $
 
@@ -1038,4 +1038,5 @@
 
   G4String& rebuildName = newValue;
+
   G4VViewer* viewer = fpVisManager -> GetViewer (rebuildName);
   if (!viewer) {
@@ -1048,5 +1049,19 @@
   }
 
+  G4VSceneHandler* sceneHandler = viewer->GetSceneHandler();
+  if (!sceneHandler) {
+    if (verbosity >= G4VisManager::errors) {
+      G4cout << "ERROR: Viewer \"" << viewer->GetName() << "\"" <<
+	" has no scene handler - report serious bug."
+	     << G4endl;
+    }
+    return;
+  }
+
+  sceneHandler->ClearTransientStore();
   viewer->NeedKernelVisit();
+  viewer->SetView();
+  viewer->ClearView();
+  viewer->DrawView();
 
   // Check auto-refresh and print confirmations, but without changing
Index: /trunk/source/visualization/management/src/G4VisManager.cc
===================================================================
--- /trunk/source/visualization/management/src/G4VisManager.cc	(revision 1287)
+++ /trunk/source/visualization/management/src/G4VisManager.cc	(revision 1288)
@@ -24,5 +24,5 @@
 // ********************************************************************
 //
-// $Id: G4VisManager.cc,v 1.124 2010/05/11 11:02:19 allison Exp $
+// $Id: G4VisManager.cc,v 1.128 2010/06/01 16:08:15 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -79,5 +79,7 @@
 G4VisManager* G4VisManager::fpInstance = 0;
 
-G4VisManager::G4VisManager ():
+G4VisManager::Verbosity G4VisManager::fVerbosity = G4VisManager::warnings;
+
+G4VisManager::G4VisManager (const G4String& verbosityString):
   fVerbose         (1),
   fInitialised     (false),
@@ -87,5 +89,4 @@
   fpSceneHandler   (0),
   fpViewer         (0),
-  fVerbosity       (warnings),
   fpStateDependent (0),
   fEventRefreshing          (false),
@@ -101,4 +102,5 @@
   fpTrajFilterMgr = new G4VisFilterManager<G4VTrajectory>("/vis/filtering/trajectories");
   fpHitFilterMgr = new G4VisFilterManager<G4VHit>("/vis/filtering/hits");
+  fpDigiFilterMgr = new G4VisFilterManager<G4VDigi>("/vis/filtering/digi");
 
   VerbosityGuidanceStrings.push_back
@@ -123,52 +125,54 @@
       ("G4VisManager: attempt to Construct more than one VisManager.");
   }
-  else {
-
-    fpInstance = this;
-    SetConcreteInstance(this);
-
-    fpStateDependent = new G4VisStateDependent (this);
-    // No need to delete this; G4StateManager does this.
-
-    if (fVerbosity >= startup) {
-      G4cout << "Visualization Manager instantiating..." << G4endl;
-    }
-
-    // Note: The specific graphics systems must be instantiated in a
-    // higher level library to avoid circular dependencies.  Also,
-    // some specifically need additional external libararies that the
-    // user must supply.  Therefore we ask the user to implement
-    // RegisterGraphicsSystems() and RegisterModelFactories()
-    // in a subclass.  We have to wait for the subclass to instantiate
-    // so RegisterGraphicsSystems() cannot be called from this
-    // constructor; it is called from Initialise().  So we ask the
-    // user:
-    //   (a) to write a subclass and implement  RegisterGraphicsSystems()
-    //       and RegisterModelFactories().  See
-    //       visualization/include/G4VisExecutive.hh/icc as an example.
-    //   (b) instantiate the subclass.
-    //   (c) invoke the Initialise() method of the subclass.
-    // For example:
-    //   ...
-    // #ifdef G4VIS_USE
-    //   // Instantiate and initialise Visualization Manager.
-    //   G4VisManager* visManager = new G4VisExecutive;
-    //   visManager -> SetVerboseLevel (Verbose);
-    //   visManager -> Initialise ();
-    // #endif
-    //   // (Don't forget to delete visManager;)
-    //   ...
-
-    // Make top level command directory...
-    G4UIcommand* directory;
-    directory = new G4UIdirectory ("/vis/");
-    directory -> SetGuidance ("Visualization commands.");
-    fDirectoryList.push_back (directory);
-
-    // Instantiate top level basic commands
-    G4VVisCommand::SetVisManager (this);  // Sets shared pointer
-    RegisterMessenger(new G4VisCommandVerbose);
-    RegisterMessenger(new G4VisCommandInitialize);
-  }
+
+  fpInstance = this;
+  SetConcreteInstance(this);
+
+  fpStateDependent = new G4VisStateDependent (this);
+  // No need to delete this; G4StateManager does this.
+
+  fVerbosity = GetVerbosityValue(verbosityString);
+  if (fVerbosity >= startup) {
+      G4cout
+	<< "Visualization Manager instantiating with verbosity \""
+	<< VerbosityString(fVerbosity)
+	<< "\"..." << G4endl;
+  }
+
+  // Note: The specific graphics systems must be instantiated in a
+  // higher level library to avoid circular dependencies.  Also,
+  // some specifically need additional external libararies that the
+  // user must supply.  Therefore we ask the user to implement
+  // RegisterGraphicsSystems() and RegisterModelFactories()
+  // in a subclass.  We have to wait for the subclass to instantiate
+  // so RegisterGraphicsSystems() cannot be called from this
+  // constructor; it is called from Initialise().  So we ask the
+  // user:
+  //   (a) to write a subclass and implement  RegisterGraphicsSystems()
+  //       and RegisterModelFactories().  See
+  //       visualization/include/G4VisExecutive.hh/icc as an example.
+  //   (b) instantiate the subclass.
+  //   (c) invoke the Initialise() method of the subclass.
+  // For example:
+  //   ...
+  // #ifdef G4VIS_USE
+  //   // Instantiate and initialise Visualization Manager.
+  //   G4VisManager* visManager = new G4VisExecutive;
+  //   visManager -> SetVerboseLevel (Verbose);
+  //   visManager -> Initialise ();
+  // #endif
+  //   // (Don't forget to delete visManager;)
+  //   ...
+
+  // Make top level command directory...
+  G4UIcommand* directory;
+  directory = new G4UIdirectory ("/vis/");
+  directory -> SetGuidance ("Visualization commands.");
+  fDirectoryList.push_back (directory);
+
+  // Instantiate top level basic commands
+  G4VVisCommand::SetVisManager (this);  // Sets shared pointer
+  RegisterMessenger(new G4VisCommandVerbose);
+  RegisterMessenger(new G4VisCommandInitialize);
 }
 
@@ -200,7 +204,8 @@
   }
 
+  delete fpDigiFilterMgr;
+  delete fpHitFilterMgr;
+  delete fpTrajFilterMgr;
   delete fpTrajDrawModelMgr;
-  delete fpTrajFilterMgr;
-  delete fpHitFilterMgr;
 }
 
@@ -288,4 +293,10 @@
   directory -> SetGuidance ("Create hit filters and messengers.");
   fDirectoryList.push_back (directory);
+  directory = new G4UIdirectory ("/vis/filtering/digi/");
+  directory -> SetGuidance ("Digi filtering commands.");
+  fDirectoryList.push_back (directory);
+  directory = new G4UIdirectory ("/vis/filtering/digi/create/");
+  directory -> SetGuidance ("Create digi filters and messengers.");
+  fDirectoryList.push_back (directory);
 
   RegisterMessengers ();
@@ -436,4 +447,15 @@
 }
 
+void G4VisManager::RegisterModel(G4VFilter<G4VDigi>* model)
+{
+  fpDigiFilterMgr->Register(model);
+}
+
+void
+G4VisManager::RegisterModelFactory(G4DigiFilterFactory* factory)
+{
+  fpDigiFilterMgr->Register(factory);
+}
+
 void G4VisManager::SelectTrajectoryModel(const G4String& model) 
 {
@@ -613,4 +635,11 @@
     ClearTransientStoreIfMarked();
     fpSceneHandler -> AddCompound (hit);
+  }
+}
+
+void G4VisManager::Draw (const G4VDigi& digi) {
+  if (IsValidView ()) {
+    ClearTransientStoreIfMarked();
+    fpSceneHandler -> AddCompound (digi);
   }
 }
@@ -872,4 +901,33 @@
 }   
 
+G4bool G4VisManager::FilterDigi(const G4VDigi& digi)
+{
+  return fpDigiFilterMgr->Accept(digi);
+}   
+
+void G4VisManager::DispatchToModel(const G4VTrajectory& trajectory)
+{
+  G4bool visible(true);
+
+  // See if trajectory passes filter
+  G4bool passed = FilterTrajectory(trajectory);
+
+  if (!passed) {
+    // Draw invisible trajectory if trajectory failed filter and
+    // are filtering in soft mode
+    if (fpTrajFilterMgr->GetMode() == FilterMode::Soft) visible = false;
+    else {return;}
+  }
+
+  // Go on to draw trajectory
+  assert (0 != fpTrajDrawModelMgr);
+
+  const G4VTrajectoryModel* trajectoryModel = CurrentTrajDrawModel();
+
+  assert (0 != trajectoryModel); // Should exist
+
+  trajectoryModel->Draw(trajectory, visible);
+}
+
 void G4VisManager::DispatchToModel(const G4VTrajectory& trajectory, G4int i_mode)
 {
@@ -902,19 +960,8 @@
     }
   } else {
-    //G4Exception("G4VisManager::DispatchToModel: Not a G4TrajectoriesModel.");
     // Just draw at user's request
     trajectoryModel->Draw(trajectory, i_mode, visible);
-    static G4bool warnedAboutIMode = false;
-    if (!warnedAboutIMode) {
-      G4Exception
-        ("G4VisManager::DispatchToModel",
-         "",
-         JustWarning,
-  "WARNING: DEPRECATED: The use of the i_mode argument in DrawTrajectory"
-  "\n  is deprecated and will be removed at the next major release.");
-      warnedAboutIMode = true;
-    }
-   }
-} 
+  }
+}
 
 void G4VisManager::SetUserAction
@@ -1105,4 +1152,5 @@
   RegisterMessenger(new G4VisCommandSceneAddGhosts);
   RegisterMessenger(new G4VisCommandSceneAddHits);
+  RegisterMessenger(new G4VisCommandSceneAddDigis);
   RegisterMessenger(new G4VisCommandSceneAddLogicalVolume);
   RegisterMessenger(new G4VisCommandSceneAddLogo);
@@ -1166,4 +1214,10 @@
   RegisterMessenger(new G4VisCommandManagerMode< G4VisFilterManager<G4VHit> >
                     (fpHitFilterMgr, fpHitFilterMgr->Placement()));
+
+  // Digi filter manager commands
+  RegisterMessenger(new G4VisCommandListManagerList< G4VisFilterManager<G4VDigi> >
+                    (fpDigiFilterMgr, fpDigiFilterMgr->Placement()));
+  RegisterMessenger(new G4VisCommandManagerMode< G4VisFilterManager<G4VDigi> >
+                    (fpDigiFilterMgr, fpDigiFilterMgr->Placement()));
 }
 
@@ -1402,8 +1456,9 @@
 	"  Only useful if before starting the run:"
 	"\n    a) trajectories are stored (\"/vis/scene/add/trajectories [smooth|rich]\"), or"
-	"\n    b) the Draw method of any hits is implemented."
-	"\n  To view trajectories and hits:"
+	"\n    b) the Draw method of any hits or digis is implemented."
+	"\n  To view trajectories, hits or digis:"
 	"\n    open a viewer, draw a volume, \"/vis/scene/add/trajectories\""
-	"\n    \"/vis/scene/add/hits\" and, possibly, \"/vis/viewer/flush\"."
+	"\n    \"/vis/scene/add/hits\" or \"/vis/scene/add/digitisations\""
+	"\n    and, possibly, \"/vis/viewer/flush\"."
 	"\n  To see all events: \"/vis/scene/endOfEventAction accumulate\"."
 	"\n  To see events individually: \"/vis/reviewKeptEvents\"."
Index: /trunk/source/visualization/modeling/History
===================================================================
--- /trunk/source/visualization/modeling/History	(revision 1287)
+++ /trunk/source/visualization/modeling/History	(revision 1288)
@@ -1,3 +1,3 @@
-$Id: History,v 1.117 2010/05/11 11:58:41 allison Exp $
+$Id: History,v 1.119 2010/05/30 11:24:57 allison Exp $
 -------------------------------------------------------------------
 
@@ -20,4 +20,15 @@
 History file for visualization/modeling
 ---------------------------------------
+
+30th May 2010  John Allison  (modeling-V09-03-02)
+- Added G4DigiModel and G4DigiFilterFactories.
+- G4BoundingSphereScene, G4PhysicalVolumeMassScene,
+  G4PhysicalVolumeSearchScene:
+  o Added AddCompound(const G4VDigi&).
+
+28th May 2010  John Allison  (modeling-V09-03-01)
+- G4TrajectoryDrawByAttribute.cc, G4TrajectoryDrawByCharge.cc,
+  G4TrajectoryDrawByOriginVolume.cc, G4TrajectoryDrawByParticleID.cc:
+  o Fixed unused parameter 'i_mode' warning.
 
 11th May 2010  John Allison  (modeling-V09-03-00)
Index: /trunk/source/visualization/modeling/include/G4BoundingSphereScene.hh
===================================================================
--- /trunk/source/visualization/modeling/include/G4BoundingSphereScene.hh	(revision 1287)
+++ /trunk/source/visualization/modeling/include/G4BoundingSphereScene.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4BoundingSphereScene.hh,v 1.19 2009/10/21 14:17:33 allison Exp $
+// $Id: G4BoundingSphereScene.hh,v 1.20 2010/05/30 11:23:25 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -71,4 +71,5 @@
   void AddCompound (const G4VTrajectory&) {}
   void AddCompound (const G4VHit&) {}
+  void AddCompound (const G4VDigi&) {}
   void AddCompound (const G4THitsMap<G4double>&) {}
   G4VisExtent GetBoundingSphereExtent ();
Index: /trunk/source/visualization/modeling/include/G4PhysicalVolumeMassScene.hh
===================================================================
--- /trunk/source/visualization/modeling/include/G4PhysicalVolumeMassScene.hh	(revision 1287)
+++ /trunk/source/visualization/modeling/include/G4PhysicalVolumeMassScene.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4PhysicalVolumeMassScene.hh,v 1.10 2009/10/21 14:17:33 allison Exp $
+// $Id: G4PhysicalVolumeMassScene.hh,v 1.11 2010/05/30 11:23:25 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -109,4 +109,5 @@
   void AddCompound (const G4VTrajectory&) {}
   void AddCompound (const G4VHit&) {}
+  void AddCompound (const G4VDigi&) {}
   void AddCompound (const G4THitsMap<G4double>&) {}
 
Index: /trunk/source/visualization/modeling/include/G4PhysicalVolumeSearchScene.hh
===================================================================
--- /trunk/source/visualization/modeling/include/G4PhysicalVolumeSearchScene.hh	(revision 1287)
+++ /trunk/source/visualization/modeling/include/G4PhysicalVolumeSearchScene.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4PhysicalVolumeSearchScene.hh,v 1.19 2009/10/21 14:17:33 allison Exp $
+// $Id: G4PhysicalVolumeSearchScene.hh,v 1.20 2010/05/30 11:23:25 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -74,4 +74,5 @@
   void AddCompound (const G4VTrajectory&) {}
   void AddCompound (const G4VHit&) {}
+  void AddCompound (const G4VDigi&) {}
   void AddCompound (const G4THitsMap<G4double>&) {}
   G4int                GetFoundDepth          () const;
Index: /trunk/source/visualization/modeling/src/G4HitFilterFactories.cc
===================================================================
--- /trunk/source/visualization/modeling/src/G4HitFilterFactories.cc	(revision 1287)
+++ /trunk/source/visualization/modeling/src/G4HitFilterFactories.cc	(revision 1288)
@@ -24,9 +24,9 @@
 // ********************************************************************
 //
-/// $Id: G4HitFilterFactories.cc,v 1.1 2006/09/12 18:53:03 tinslay Exp $
+/// $Id: G4HitFilterFactories.cc,v 1.2 2010/05/30 11:24:03 allison Exp $
 // GEANT4 tag $Name:  $
 //
 //
-// Trajectory filter model factories creating filters
+// Hits filter model factories creating filters
 // and associated messengers.
 //
Index: /trunk/source/visualization/modeling/src/G4TrajectoryDrawByAttribute.cc
===================================================================
--- /trunk/source/visualization/modeling/src/G4TrajectoryDrawByAttribute.cc	(revision 1287)
+++ /trunk/source/visualization/modeling/src/G4TrajectoryDrawByAttribute.cc	(revision 1288)
@@ -24,5 +24,5 @@
 // ********************************************************************
 //
-// $Id: G4TrajectoryDrawByAttribute.cc,v 1.4 2010/05/11 11:31:31 allison Exp $
+// $Id: G4TrajectoryDrawByAttribute.cc,v 1.5 2010/05/28 02:00:59 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -63,5 +63,5 @@
 void
 G4TrajectoryDrawByAttribute::Draw(const G4VTrajectory& object,
-				  const G4int& i_mode,
+				  const G4int&,
 				  const G4bool& visible) const
 {
Index: /trunk/source/visualization/modeling/src/G4TrajectoryDrawByCharge.cc
===================================================================
--- /trunk/source/visualization/modeling/src/G4TrajectoryDrawByCharge.cc	(revision 1287)
+++ /trunk/source/visualization/modeling/src/G4TrajectoryDrawByCharge.cc	(revision 1288)
@@ -24,5 +24,5 @@
 // ********************************************************************
 //
-// $Id: G4TrajectoryDrawByCharge.cc,v 1.9 2010/05/11 11:31:31 allison Exp $
+// $Id: G4TrajectoryDrawByCharge.cc,v 1.10 2010/05/28 02:00:59 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -58,5 +58,5 @@
 void
 G4TrajectoryDrawByCharge::Draw(const G4VTrajectory& object,
-			       const G4int& i_mode,
+			       const G4int&,
 			       const G4bool& visible) const
 {
Index: /trunk/source/visualization/modeling/src/G4TrajectoryDrawByOriginVolume.cc
===================================================================
--- /trunk/source/visualization/modeling/src/G4TrajectoryDrawByOriginVolume.cc	(revision 1287)
+++ /trunk/source/visualization/modeling/src/G4TrajectoryDrawByOriginVolume.cc	(revision 1288)
@@ -24,5 +24,5 @@
 // ********************************************************************
 //
-// $Id: G4TrajectoryDrawByOriginVolume.cc,v 1.5 2010/05/11 11:31:31 allison Exp $
+// $Id: G4TrajectoryDrawByOriginVolume.cc,v 1.6 2010/05/28 02:00:59 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -46,5 +46,5 @@
 void
 G4TrajectoryDrawByOriginVolume::Draw(const G4VTrajectory& object,
-				     const G4int& i_mode,
+				     const G4int&,
 				     const G4bool& visible) const
 {
Index: /trunk/source/visualization/modeling/src/G4TrajectoryDrawByParticleID.cc
===================================================================
--- /trunk/source/visualization/modeling/src/G4TrajectoryDrawByParticleID.cc	(revision 1287)
+++ /trunk/source/visualization/modeling/src/G4TrajectoryDrawByParticleID.cc	(revision 1288)
@@ -24,5 +24,5 @@
 // ********************************************************************
 //
-// $Id: G4TrajectoryDrawByParticleID.cc,v 1.9 2010/05/11 11:31:31 allison Exp $
+// $Id: G4TrajectoryDrawByParticleID.cc,v 1.10 2010/05/28 02:00:59 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -44,5 +44,5 @@
 void
 G4TrajectoryDrawByParticleID::Draw(const G4VTrajectory& object,
-				   const G4int& i_mode,
+				   const G4int&,
 				   const G4bool& visible) const
 {

Index: /trunk/source/visualization/management/include/G4VSceneHandler.hh
===================================================================
--- /trunk/source/visualization/management/include/G4VSceneHandler.hh	(revision 1287)
+++ /trunk/source/visualization/management/include/G4VSceneHandler.hh	(revision 1288)
@@ -25,5 +25,5 @@
 //
 //
-// $Id: G4VSceneHandler.hh,v 1.43 2010/05/11 10:50:57 allison Exp $
+// $Id: G4VSceneHandler.hh,v 1.44 2010/05/30 11:30:49 allison Exp $
 // GEANT4 tag $Name:  $
 //
@@ -59,4 +59,5 @@
 class G4Event;
 class G4AttHolder;
+class G4VDigi;
 
 class G4VSceneHandler: public G4VGraphicsScene {
@@ -129,4 +130,5 @@
   virtual void AddCompound (const G4VTrajectory&);
   virtual void AddCompound (const G4VHit&);
+  virtual void AddCompound (const G4VDigi&);
   virtual void AddCompound (const G4THitsMap<G4double>&);
 
@@ -319,8 +321,8 @@
   // object onto the G4AttHolder object.  It checks fpModel, and also
   // loads the G4AttValues and G4AttDefs from G4PhysicalVolumeModel,
   // G4VTrajectory, G4VTrajectoryPoint, or G4VHits, as appropriate.
   // The G4AttHolder object is an object of a class that publicly
   // inherits G4AttHolder - see, e.g., SoG4Polyhedron in the Open
   // Inventor driver.  G4AttHolder deletes G4AttValues in its
   // destructor to ensure proper clean-up of G4AttValues.
 
@@ -319,8 +321,8 @@
   // object onto the G4AttHolder object.  It checks fpModel, and also
   // loads the G4AttValues and G4AttDefs from G4PhysicalVolumeModel,
-  // G4VTrajectory, G4VTrajectoryPoint, or G4VHits, as appropriate.
-  // The G4AttHolder object is an object of a class that publicly
-  // inherits G4AttHolder - see, e.g., SoG4Polyhedron in the Open
-  // Inventor driver.  G4AttHolder deletes G4AttValues in its
+  // G4VTrajectory, G4VTrajectoryPoint, G4VHit or G4VDigi, as
+  // appropriate.  The G4AttHolder object is an object of a class that
+  // publicly inherits G4AttHolder - see, e.g., SoG4Polyhedron in the
+  // Open Inventor driver.  G4AttHolder deletes G4AttValues in its
   // destructor to ensure proper clean-up of G4AttValues.
 